@@ -1,12 +1,12 @@
-/* SPDX-License-Identifier: GPL-2.0
- *
- * Copyright (C) 2015-2018 Jason A. Donenfeld <Jason@zx2c4.com>. All Rights Reserved.
+// SPDX-License-Identifier: GPL-2.0
+/*
+ * Copyright (C) 2015-2019 Jason A. Donenfeld <Jason@zx2c4.com>. All Rights Reserved.
  */
 
 #include "queueing.h"
 
 struct multicore_worker __percpu *
-packet_alloc_percpu_multicore_worker(work_func_t function, void *ptr)
+wg_packet_alloc_percpu_multicore_worker(work_func_t function, void *ptr)
 {
 	int cpu;
 	struct multicore_worker __percpu *worker =
@@ -15,15 +15,15 @@ packet_alloc_percpu_multicore_worker(work_func_t function, void *ptr)
 	if (!worker)
 		return NULL;
 
-	for_each_possible_cpu (cpu) {
+	for_each_possible_cpu(cpu) {
 		per_cpu_ptr(worker, cpu)->ptr = ptr;
 		INIT_WORK(&per_cpu_ptr(worker, cpu)->work, function);
 	}
 	return worker;
 }
 
-int packet_queue_init(struct crypt_queue *queue, work_func_t function,
-		      bool multicore, unsigned int len)
+int wg_packet_queue_init(struct crypt_queue *queue, work_func_t function,
+			 bool multicore, unsigned int len)
 {
 	int ret;
 
@@ -33,17 +33,18 @@ int packet_queue_init(struct crypt_queue *queue, work_func_t function,
 		return ret;
 	if (function) {
 		if (multicore) {
-			queue->worker = packet_alloc_percpu_multicore_worker(
+			queue->worker = wg_packet_alloc_percpu_multicore_worker(
 				function, queue);
 			if (!queue->worker)
 				return -ENOMEM;
-		} else
+		} else {
 			INIT_WORK(&queue->work, function);
+		}
 	}
 	return 0;
 }
 
-void packet_queue_free(struct crypt_queue *queue, bool multicore)
+void wg_packet_queue_free(struct crypt_queue *queue, bool multicore)
 {
 	if (multicore)
 		free_percpu(queue->worker);
